Axiom — Axiom 0.0.1 documentation

# Axiom

Axiom is a Python library and command-line utility for verifying metadata against a defined standard.

- Installation
- Command-line Usage
  - Validation
  - Convert CF
  - Convert CORDEX
- Metadata
  - Loading a metadata JSON
  - Extracted from an Xarray dataset
  - Defined programmatically at runtime
- Metadata Schemas
  - Global attributes
  - Variable attributes
  - Putting it all together
- Metadata Conversion
  - CF Conventions
  - CORDEX CSV
  - Saving Converted Schemas
- Validation
  - Using the Command Line
  - Using Python
- Reporting

# Indices and tables

- Index

- Module Index

- Search Page